LikelihoodExpression

Struct LikelihoodExpression 

pub struct LikelihoodExpression { /* private fields */ }
A combination of LikelihoodTerms as well as sums and products of them.

Notes

When multiple terms provide parameters with the same name, the term earliest in the expression (or argument list) defines the fixed/free status and default value.

Implementations

Source

impl LikelihoodExpression

pub fn from_term(term: Box<dyn LikelihoodTerm>) -> LadduResult<Self>

Build a LikelihoodExpression from a single LikelihoodTerm.

pub fn zero() -> Self

Create an expression representing zero, the additive identity.

pub fn one() -> Self

Create an expression representing one, the multiplicative identity.

pub fn parameters(&self) -> ParameterMap

The parameters referenced across all terms in this expression.

pub fn n_free(&self) -> usize

Number of free parameters.

pub fn n_fixed(&self) -> usize

Number of fixed parameters.

pub fn n_parameters(&self) -> usize

Total number of parameters (free + fixed).

pub fn evaluate(&self, parameters: &[f64]) -> LadduResult<f64>

Evaluate the sum/product of all terms.

pub fn evaluate_gradient(&self, parameters: &[f64]) -> LadduResult<DVector<f64>>

Evaluate the gradient.