LikelihoodExpression

Struct LikelihoodExpression 

pub struct LikelihoodExpression { /* private fields */ }
A combination of LikelihoodTerms as well as sums and products of them.

Notes

When multiple terms provide parameters with the same name, the term earliest in the expression (or argument list) defines the fixed/free status and default value.

Implementations

Source

impl LikelihoodExpression

pub fn from_term(term: Box<dyn LikelihoodTerm>) -> Self

Build a LikelihoodExpression from a single LikelihoodTerm.

pub fn zero() -> Self

Create an expression representing zero, the additive identity.

pub fn one() -> Self

Create an expression representing one, the multiplicative identity.

pub fn parameters(&self) -> Vec<String>

The parameter names referenced across all terms in this expression.

pub fn free_parameters(&self) -> Vec<String>

The free parameter names which require user-provided values.

pub fn fixed_parameters(&self) -> Vec<String>

The names of parameters with constant (fixed) values.

pub fn fix(&self, name: &str, value: f64) -> LadduResult<Self>

Return a new LikelihoodExpression with the given parameter fixed to a value.

pub fn free(&self, name: &str) -> LadduResult<Self>

Return a new LikelihoodExpression with the given parameter freed.

pub fn rename_parameter(&self, old: &str, new: &str) -> LadduResult<Self>

Return a new LikelihoodExpression with the given parameter renamed.

pub fn rename_parameters( &self, mapping: &HashMap<String, String>, ) -> LadduResult<Self>

Return a new LikelihoodExpression with several parameters renamed.

pub fn load(&self) -> LikelihoodEvaluator

Load a LikelihoodExpression so it can be evaluated repeatedly.