MaybeThreadPool

Struct MaybeThreadPool 

pub struct MaybeThreadPool { /* private fields */ }
A wrapper for the requested thread-count policy used by optimization callbacks.

Implementations

Source

impl MaybeThreadPool

pub fn new(num_threads: usize) -> Self

Crate a new thread pool with the given number of threads. This is typically used as user-data for ganesh optimizations.

pub fn install<R: Send>( &self, op: impl FnOnce() -> LadduResult<R> + Send, ) -> LadduResult<R>

Run the given operation on the current thread pool.