pub struct LikelihoodExpression { /* private fields */ }Expand description
A combination of LikelihoodTerms as well as sums and products of them.
Notes
When multiple terms provide parameters with the same name, the term earliest in the expression (or argument list) defines the fixed/free status and default value.
Implementations
Sourceimpl LikelihoodExpression
impl LikelihoodExpression
Sourcepub fn from_term(term: Box<dyn LikelihoodTerm>) -> LadduResult<Self>
pub fn from_term(term: Box<dyn LikelihoodTerm>) -> LadduResult<Self>
Build a LikelihoodExpression from a single LikelihoodTerm.
Sourcepub fn parameters(&self) -> ParameterMap
pub fn parameters(&self) -> ParameterMap
The parameters referenced across all terms in this expression.
Sourcepub fn n_parameters(&self) -> usize
pub fn n_parameters(&self) -> usize
Total number of parameters (free + fixed).
Sourcepub fn evaluate(&self, parameters: &[f64]) -> LadduResult<f64>
pub fn evaluate(&self, parameters: &[f64]) -> LadduResult<f64>
Evaluate the sum/product of all terms.
Sourcepub fn evaluate_gradient(&self, parameters: &[f64]) -> LadduResult<DVector<f64>>
pub fn evaluate_gradient(&self, parameters: &[f64]) -> LadduResult<DVector<f64>>
Evaluate the gradient.