pub struct NLL {
pub data_evaluator: Evaluator,
pub accmc_evaluator: Evaluator,
/* private fields */
}Expand description
An extended, unbinned negative log-likelihood evaluator.
Fields
data_evaluator: EvaluatorThe internal Evaluator for data
accmc_evaluator: EvaluatorThe internal Evaluator for accepted Monte Carlo
Implementations
Sourceimpl NLL
impl NLL
Sourcepub fn new(
expression: &Expression,
ds_data: &Arc<Dataset>,
ds_accmc: &Arc<Dataset>,
n_mc: Option<f64>,
) -> LadduResult<Box<Self>>
pub fn new( expression: &Expression, ds_data: &Arc<Dataset>, ds_accmc: &Arc<Dataset>, n_mc: Option<f64>, ) -> LadduResult<Box<Self>>
Construct an NLL from an Expression and two Datasets (data and Monte Carlo). This mirrors loading a model but starts from
the expression directly. The number of Monte Carlo events used in the denominator of the
normalization integral may also be specified (uses the weighted number of accepted Monte
Carlo events if None is given).
Sourcepub fn parameters(&self) -> ParameterMap
pub fn parameters(&self) -> ParameterMap
The parameters for this NLL.
Sourcepub fn n_parameters(&self) -> usize
pub fn n_parameters(&self) -> usize
Total number of parameters.
Sourcepub fn expression(&self) -> Expression
pub fn expression(&self) -> Expression
Returns the expression represented by this NLL.
Sourcepub fn compiled_expression(&self) -> CompiledExpression
pub fn compiled_expression(&self) -> CompiledExpression
Returns a tree-like diagnostic snapshot of the compiled expression for this NLL’s current active-amplitude mask.
Sourcepub fn to_stochastic(
&self,
batch_size: usize,
seed: Option<usize>,
) -> LadduResult<StochasticNLL>
pub fn to_stochastic( &self, batch_size: usize, seed: Option<usize>, ) -> LadduResult<StochasticNLL>
Create a new StochasticNLL from this NLL.
Sourcepub fn activate<T: AsRef<str>>(&self, name: T)
pub fn activate<T: AsRef<str>>(&self, name: T)
Activate an Amplitude by tag, skipping missing entries.
Sourcepub fn activate_strict<T: AsRef<str>>(&self, name: T) -> LadduResult<()>
pub fn activate_strict<T: AsRef<str>>(&self, name: T) -> LadduResult<()>
Activate an Amplitude by tag and return an error if it is missing.
Sourcepub fn activate_many<T: AsRef<str>>(&self, names: &[T])
pub fn activate_many<T: AsRef<str>>(&self, names: &[T])
Activate several Amplitudes by tag, skipping missing entries.
Sourcepub fn activate_many_strict<T: AsRef<str>>(
&self,
names: &[T],
) -> LadduResult<()>
pub fn activate_many_strict<T: AsRef<str>>( &self, names: &[T], ) -> LadduResult<()>
Activate several Amplitudes by tag and return an error if any are missing.
Sourcepub fn activate_all(&self)
pub fn activate_all(&self)
Activate all registered Amplitudes.
Sourcepub fn deactivate<T: AsRef<str>>(&self, name: T)
pub fn deactivate<T: AsRef<str>>(&self, name: T)
Deactivate an Amplitude by tag, skipping missing entries.
Sourcepub fn deactivate_strict<T: AsRef<str>>(&self, name: T) -> LadduResult<()>
pub fn deactivate_strict<T: AsRef<str>>(&self, name: T) -> LadduResult<()>
Deactivate an Amplitude by tag and return an error if it is missing.
Sourcepub fn deactivate_many<T: AsRef<str>>(&self, names: &[T])
pub fn deactivate_many<T: AsRef<str>>(&self, names: &[T])
Deactivate several Amplitudes by tag, skipping missing entries.
Sourcepub fn deactivate_many_strict<T: AsRef<str>>(
&self,
names: &[T],
) -> LadduResult<()>
pub fn deactivate_many_strict<T: AsRef<str>>( &self, names: &[T], ) -> LadduResult<()>
Deactivate several Amplitudes by tag and return an error if any are missing.
Sourcepub fn deactivate_all(&self)
pub fn deactivate_all(&self)
Deactivate all registered Amplitudes.
Sourcepub fn isolate<T: AsRef<str>>(&self, name: T)
pub fn isolate<T: AsRef<str>>(&self, name: T)
Isolate an Amplitude by tag (deactivate the rest), skipping missing entries.
Sourcepub fn isolate_strict<T: AsRef<str>>(&self, name: T) -> LadduResult<()>
pub fn isolate_strict<T: AsRef<str>>(&self, name: T) -> LadduResult<()>
Isolate an Amplitude by tag (deactivate the rest) and return an error if it is missing.
Sourcepub fn isolate_many<T: AsRef<str>>(&self, names: &[T])
pub fn isolate_many<T: AsRef<str>>(&self, names: &[T])
Isolate several Amplitudes by tag (deactivate the rest), skipping missing entries.
Sourcepub fn isolate_many_strict<T: AsRef<str>>(&self, names: &[T]) -> LadduResult<()>
pub fn isolate_many_strict<T: AsRef<str>>(&self, names: &[T]) -> LadduResult<()>
Isolate several Amplitudes by tag (deactivate the rest) and return an error if any are missing.
Sourcepub fn project_weights_local(
&self,
parameters: &[f64],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<Vec<f64>>
pub fn project_weights_local( &self, parameters: &[f64], mc_evaluator: Option<Evaluator>, ) -> LadduResult<Vec<f64>>
Project the stored Expression over the events in the Dataset stored by the
Evaluator with the given values for free parameters to obtain weights for each
Monte-Carlo event (non-MPI version).
Notes
This method is not intended to be called in analyses but rather in writing methods
that have mpi-feature-gated versions. Most users will want to call NLL::project_weights instead.
Sourcepub fn project_weights(
&self,
parameters: &[f64],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<Vec<f64>>
pub fn project_weights( &self, parameters: &[f64], mc_evaluator: Option<Evaluator>, ) -> LadduResult<Vec<f64>>
Project the stored Expression over the events in the Dataset stored by the
Evaluator with the given values for free parameters to obtain weights for each
Monte-Carlo event. This method takes the real part of the given expression (discarding
the imaginary part entirely, which does not matter if expressions are coherent sums
wrapped in Expression::norm_sqr.
Event weights are determined by the following formula:
\text{weight}(\vec{p}; e) = \text{weight}(e) \mathcal{L}(e) / N_{\text{MC}}Note that $N_{\text{MC}}$ will always be the number of accepted Monte Carlo events,
regardless of the mc_evaluator.
Sourcepub fn project_weights_and_gradients_local(
&self,
parameters: &[f64],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
pub fn project_weights_and_gradients_local( &self, parameters: &[f64], mc_evaluator: Option<Evaluator>, ) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
Project the stored Expression over the events in the Dataset stored by the
Evaluator with the given values for free parameters to obtain weights and gradients of
those weights for each Monte-Carlo event (non-MPI version).
Notes
This method is not intended to be called in analyses but rather in writing methods
that have mpi-feature-gated versions. Most users will want to call NLL::project_weights_and_gradients instead.
Sourcepub fn project_weights_and_gradients(
&self,
parameters: &[f64],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
pub fn project_weights_and_gradients( &self, parameters: &[f64], mc_evaluator: Option<Evaluator>, ) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
Project the stored Expression over the events in the Dataset stored by the
Evaluator with the given values for free parameters to obtain weights and gradients of
those weights for each Monte-Carlo event. This method takes the real part of the given
expression (discarding the imaginary part entirely, which does not matter if expressions
are coherent sums wrapped in Expression::norm_sqr.
Event weights are determined by the following formula:
\text{weight}(\vec{p}; e) = \text{weight}(e) \mathcal{L}(e) / N_{\text{MC}}Note that $N_{\text{MC}}$ will always be the number of accepted Monte Carlo events,
regardless of the mc_evaluator.
Sourcepub fn project_weights_subset_local<T: AsRef<str>>(
&self,
parameters: &[f64],
names: &[T],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<Vec<f64>>
pub fn project_weights_subset_local<T: AsRef<str>>( &self, parameters: &[f64], names: &[T], mc_evaluator: Option<Evaluator>, ) -> LadduResult<Vec<f64>>
Project the model over one isolated amplitude subset in local execution, skipping missing amplitude tags.
Sourcepub fn project_weights_subset_local_strict<T: AsRef<str>>(
&self,
parameters: &[f64],
names: &[T],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<Vec<f64>>
pub fn project_weights_subset_local_strict<T: AsRef<str>>( &self, parameters: &[f64], names: &[T], mc_evaluator: Option<Evaluator>, ) -> LadduResult<Vec<f64>>
Project the model over one isolated amplitude subset in local execution and return an error if any requested amplitude tag is missing.
Sourcepub fn project_weights_subset<T: AsRef<str>>(
&self,
parameters: &[f64],
names: &[T],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<Vec<f64>>
pub fn project_weights_subset<T: AsRef<str>>( &self, parameters: &[f64], names: &[T], mc_evaluator: Option<Evaluator>, ) -> LadduResult<Vec<f64>>
Project the model over one isolated amplitude subset, skipping missing amplitude names.
Sourcepub fn project_weights_subset_strict<T: AsRef<str>>(
&self,
parameters: &[f64],
names: &[T],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<Vec<f64>>
pub fn project_weights_subset_strict<T: AsRef<str>>( &self, parameters: &[f64], names: &[T], mc_evaluator: Option<Evaluator>, ) -> LadduResult<Vec<f64>>
Project the model over one isolated amplitude subset and return an error if any requested amplitude tag is missing.
Sourcepub fn project_weights_subsets_local<T: AsRef<str>>(
&self,
parameters: &[f64],
subsets: &[Vec<T>],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<Vec<Vec<f64>>>
pub fn project_weights_subsets_local<T: AsRef<str>>( &self, parameters: &[f64], subsets: &[Vec<T>], mc_evaluator: Option<Evaluator>, ) -> LadduResult<Vec<Vec<f64>>>
Project the model over multiple isolated amplitude subsets in local execution, skipping missing amplitude tags within each subset.
Sourcepub fn project_weights_subsets_local_strict<T: AsRef<str>>(
&self,
parameters: &[f64],
subsets: &[Vec<T>],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<Vec<Vec<f64>>>
pub fn project_weights_subsets_local_strict<T: AsRef<str>>( &self, parameters: &[f64], subsets: &[Vec<T>], mc_evaluator: Option<Evaluator>, ) -> LadduResult<Vec<Vec<f64>>>
Project the model over multiple isolated amplitude subsets in local execution and return an error if any requested amplitude tag is missing.
Sourcepub fn project_weights_subsets<T: AsRef<str>>(
&self,
parameters: &[f64],
subsets: &[Vec<T>],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<Vec<Vec<f64>>>
pub fn project_weights_subsets<T: AsRef<str>>( &self, parameters: &[f64], subsets: &[Vec<T>], mc_evaluator: Option<Evaluator>, ) -> LadduResult<Vec<Vec<f64>>>
Project the model over multiple isolated amplitude subsets, skipping missing amplitude tags within each subset.
Sourcepub fn project_weights_subsets_strict<T: AsRef<str>>(
&self,
parameters: &[f64],
subsets: &[Vec<T>],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<Vec<Vec<f64>>>
pub fn project_weights_subsets_strict<T: AsRef<str>>( &self, parameters: &[f64], subsets: &[Vec<T>], mc_evaluator: Option<Evaluator>, ) -> LadduResult<Vec<Vec<f64>>>
Project the model over multiple isolated amplitude subsets and return an error if any requested amplitude tag is missing.
Sourcepub fn project_weights_and_gradients_subset_local<T: AsRef<str>>(
&self,
parameters: &[f64],
names: &[T],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
pub fn project_weights_and_gradients_subset_local<T: AsRef<str>>( &self, parameters: &[f64], names: &[T], mc_evaluator: Option<Evaluator>, ) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
Project the model and parameter gradients over one isolated amplitude subset in local execution, skipping missing amplitude tags.
Sourcepub fn project_weights_and_gradients_subset_local_strict<T: AsRef<str>>(
&self,
parameters: &[f64],
names: &[T],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
pub fn project_weights_and_gradients_subset_local_strict<T: AsRef<str>>( &self, parameters: &[f64], names: &[T], mc_evaluator: Option<Evaluator>, ) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
Project the model and parameter gradients over one isolated amplitude subset in local execution and return an error if any requested amplitude tag is missing.
Sourcepub fn project_weights_and_gradients_subset<T: AsRef<str>>(
&self,
parameters: &[f64],
names: &[T],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
pub fn project_weights_and_gradients_subset<T: AsRef<str>>( &self, parameters: &[f64], names: &[T], mc_evaluator: Option<Evaluator>, ) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
Project the model and parameter gradients over one isolated amplitude subset, skipping missing amplitude tags.
Sourcepub fn project_weights_and_gradients_subset_strict<T: AsRef<str>>(
&self,
parameters: &[f64],
names: &[T],
mc_evaluator: Option<Evaluator>,
) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
pub fn project_weights_and_gradients_subset_strict<T: AsRef<str>>( &self, parameters: &[f64], names: &[T], mc_evaluator: Option<Evaluator>, ) -> LadduResult<(Vec<f64>, Vec<DVector<f64>>)>
Project the model and parameter gradients over one isolated amplitude subset and return an error if any requested amplitude tag is missing.