pub struct LikelihoodExpression { /* private fields */ }Expand description
A combination of LikelihoodTerms as well as sums and products of them.
Notes
When multiple terms provide parameters with the same name, the term earliest in the expression (or argument list) defines the fixed/free status and default value.
Implementations
Sourceimpl LikelihoodExpression
impl LikelihoodExpression
Sourcepub fn from_term(term: Box<dyn LikelihoodTerm>) -> Self
pub fn from_term(term: Box<dyn LikelihoodTerm>) -> Self
Build a LikelihoodExpression from a single LikelihoodTerm.
Sourcepub fn parameters(&self) -> Vec<String>
pub fn parameters(&self) -> Vec<String>
The parameter names referenced across all terms in this expression.
Sourcepub fn free_parameters(&self) -> Vec<String>
pub fn free_parameters(&self) -> Vec<String>
The free parameter names which require user-provided values.
Sourcepub fn fixed_parameters(&self) -> Vec<String>
pub fn fixed_parameters(&self) -> Vec<String>
The names of parameters with constant (fixed) values.
Sourcepub fn fix(&self, name: &str, value: f64) -> LadduResult<Self>
pub fn fix(&self, name: &str, value: f64) -> LadduResult<Self>
Return a new LikelihoodExpression with the given parameter fixed to a value.
Sourcepub fn free(&self, name: &str) -> LadduResult<Self>
pub fn free(&self, name: &str) -> LadduResult<Self>
Return a new LikelihoodExpression with the given parameter freed.
Sourcepub fn rename_parameter(&self, old: &str, new: &str) -> LadduResult<Self>
pub fn rename_parameter(&self, old: &str, new: &str) -> LadduResult<Self>
Return a new LikelihoodExpression with the given parameter renamed.
Sourcepub fn rename_parameters(
&self,
mapping: &HashMap<String, String>,
) -> LadduResult<Self>
pub fn rename_parameters( &self, mapping: &HashMap<String, String>, ) -> LadduResult<Self>
Return a new LikelihoodExpression with several parameters renamed.
Sourcepub fn load(&self) -> LikelihoodEvaluator
pub fn load(&self) -> LikelihoodEvaluator
Load a LikelihoodExpression so it can be evaluated repeatedly.