pub struct MaybeThreadPool { /* private fields */ }Expand description
A wrapper for the requested thread-count policy used by optimization callbacks.
Implementations
Sourceimpl MaybeThreadPool
impl MaybeThreadPool
Sourcepub fn new(num_threads: usize) -> Self
pub fn new(num_threads: usize) -> Self
Crate a new thread pool with the given number of threads. This is typically used as
user-data for ganesh optimizations.
Sourcepub fn install<R: Send>(
&self,
op: impl FnOnce() -> LadduResult<R> + Send,
) -> LadduResult<R>
pub fn install<R: Send>( &self, op: impl FnOnce() -> LadduResult<R> + Send, ) -> LadduResult<R>
Run the given operation on the current thread pool.